import axios from 'axios'
import { Message, MessageBox } from 'element-ui'

// 创建axios实例
const service = axios.create({
  baseURL: process.env.SKILL_API, // api 的 base_url
  timeout: 5000 // 请求超时时间
})

// request拦截器
service.interceptors.request.use(
  config => {
    if (localStorage.getItem('token')) {
      config.headers['token'] = localStorage.getItem('token'); // 让每个请求携带自定义token 请根据实际情况自行修改
    }
    return config
  },
  error => {
    // Do something with request error
    console.log(error) // for debug
    Promise.reject(error)
  }
)

// response 拦截器
service.interceptors.response.use(
  response => {
    /**
     * code为非200是抛错 可结合自己业务进行修改
     */
    const res = response.data
    if (res.code !== 200) {
      Message({
        message: res.message,
        type: 'error',
        duration: 5 * 1000
      })
    } else {
      return response.data
    }
  },
  error => {
    console.log('err' + error) // for debug
    Message({
      message: error.message,
      type: 'error',
      duration: 5 * 1000
    })
    return Promise.reject(error)
  }
)


export function getSkillList (code) {
  // if (code === 'XYYF') {
  //   return service({
  //     url: `${process.env.XYYF_API}//cms/course`,
  //     method: 'get',
  //     params: {
  //       code
  //     }
  //   })
  // } else {
    return service({
      url: '/skillInfo',
      method: 'get',
      params: {
        code
      }
    })
  // }
}
export function getXyyfMobileList() {
  return service({
    url: 'http://m-xyyf-api.ai160.com/statistics/channel',
    method: 'get'
  })
}
export function getXyyfData(params) {
  return service({
    url: 'http://m-xyyf-api.ai160.com/statistics',
    method: 'get',
    params
  })
}

export function getMiFengData(params) {
  return service({
    url: 'http://resources.ai160.com/cms/statistics',
    method: 'get',
    params
  })
}

export function getSkillData (params) {
  if (params.channel === 'BAIDU') {
    return service({
      url: '/statistics',
      method: 'get',
      params
    })
  } else if (params.channel === 'XYYF') {
    return service({
      url: `http://yfxxt-api.ai160.com/statistics`,
      method: 'get',
      params: {
        startDate: params.startDate,
        endDate: params.endDate,
      }
    })
  } else {
    return service({
      url: `${process.env.XYYF_API}/statistics`,
      method: 'get',
      params: {
        courseId: params.skillId,
        startDate: params.startDate,
        endDate: params.endDate,
      }
    })
  }

}


export function getOppoData (params) {

    console.log(123123123,params)
    return service({
      url: `${process.env.OPPO_API}/statistics`,
      method: 'get',
      params: {
        channelCode: params.channel,
        startDate: params.startDate,
        endDate: params.endDate,
      }
    })


}

export function getBaiduCourseList (subjectEnum) {

  return service({
    url: `${process.env.BAIDU_API}/statistics/getSimpleCourseList`,
    method: 'get',
    params: {
      subjectEnum
    }
  })


}

export function getBaiduData (params) {

  console.log(123123123,params)
  return service({
    url: `${process.env.BAIDU_API}/statistics/simpleCourse`,
    method: 'get',
    params: {
      // courseId: params.classId,
      startDate: params.startDate,
      endDate: params.endDate,
    }
  })


}

export function getAliData (params) {

  console.log(123123123,params)
  return service({
    url: `${process.env.ali_API}/statistics`,
    method: 'get',
    params: {
      skillId: params.skillId,
      startDate: params.startDate,
      endDate: params.endDate,
    }
  })


}

